@@ -1,5 +1,5 @@
 import warnings
-from functools import lru_cache, wraps
+from functools import lru_cache
 from typing import Dict, List, Optional
 
 import numpy as np
@@ -10,7 +10,7 @@ from . import fields as fld
 from . import utils
 from .errors import InputError
 from .indicators import TA
-from .reader import SETDataReader, _SETDataReaderCached
+from .reader import _SETDataReaderCached
 
 nan = float("nan")
 
@@ -251,20 +251,22 @@ class SETSignalCreator:
             if value_by == fld.VALUE_BY_STOCK:
                 df = self._get_data_symbol_daily(symbol_list=symbol_list, field=field)
             elif value_by == fld.VALUE_BY_SECTOR:
-                df = self._sdr._get_daily_sector_info_by_security(
+                df = self._sdr._get_daily_sector_info(
                     field=field,
                     symbol_list=symbol_list,
                     start_date=self._start_date,
                     end_date=self._end_date,
                     f_data="S",
+                    is_stock_column=True,
                 )
             elif value_by == fld.VALUE_BY_INDUSTRY:
-                df = self._sdr._get_daily_sector_info_by_security(
+                df = self._sdr._get_daily_sector_info(
                     field=field,
                     symbol_list=symbol_list,
                     start_date=self._start_date,
                     end_date=self._end_date,
                     f_data="I",
+                    is_stock_column=True,
                 )
             else:
                 raise InputError(
@@ -388,19 +390,11 @@ class SETSignalCreator:
         """
         symbol_list = self._get_symbol_in_universe()
 
-        # TODO: perf - query only no trade date, symbol
-        close_df = self._get_data_symbol_daily(
-            field=fld.D_CLOSE, symbol_list=symbol_list, is_fill_prior=False
-        )
-        last_bid_df = self._get_data_symbol_daily(
-            field=fld.D_LAST_BID, symbol_list=symbol_list, is_fill_prior=False
-        )
-        last_offer_df = self._get_data_symbol_daily(
-            field=fld.D_LAST_OFFER, symbol_list=symbol_list, is_fill_prior=False
+        has_trade = self._get_data_symbol_daily(
+            field="has_trade", symbol_list=symbol_list, is_fill_prior=False
         )
 
-        out = close_df + last_bid_df + last_offer_df
-        out = ~out.fillna(0).astype(bool)
+        out = ~(has_trade.fillna(0.0).astype(bool))
         out = self._reindex(out, fill_value=True)
 
         return out
@@ -572,7 +566,7 @@ class SETSignalCreator:
         2  1.0  1.0  1.0
         """
         df = factor_df.rank(ascending=ascending, axis=1, method=method, pct=pct)
-        if quantity != None:
+        if quantity is not None:
             if quantity <= 0:
                 raise InputError(
                     f"quantity must be greater than 0. but {quantity} is given."
@@ -628,12 +622,10 @@ class SETSignalCreator:
         for i in static_index_list:
             if i in fld.MARKET_MAP_UPPER:
                 df = self._get_symbol_info(market=i)
-            elif i in fld.INDUSTRY_LIST:
-                df = self._get_symbol_info(industry=i, market=fld.MARKET_SET)
-            elif i in fld.SECTOR_LIST:
-                df = self._get_symbol_info(sector=i, market=fld.MARKET_SET)
-            elif i[:-2] in fld.INDUSTRY_LIST and i.endswith("-M"):
-                df = self._get_symbol_info(industry=i[:-2], market=fld.MARKET_MAI)
+            elif i in fld.INDUSTRY_LIST_UPPER:
+                df = self._get_symbol_info(industry=i)
+            elif i in fld.SECTOR_LIST_UPPER:
+                df = self._get_symbol_info(sector=i)
             else:
                 warnings.warn(f"Index {i} is invalid.")
                 continue
@@ -648,7 +640,6 @@ class SETSignalCreator:
 
         return sorted(set(df["symbol"]))
 
-    @wraps(SETDataReader.get_symbol_info)
     def _get_symbol_info(self, *args, **kwargs) -> pd.DataFrame:
         return self._sdr.get_symbol_info(
             *args,
@@ -825,32 +816,30 @@ class SETSignalCreator:
 
     def _is_universe_static(self, universe: str) -> pd.DataFrame:
         universe = universe.upper()
+
         symbol_list = self._get_symbol_in_universe()
         df = self._get_symbol_info(symbol_list=symbol_list).set_index(
             "symbol", drop=False
         )
-        df["market"] = df["market"].str.upper()
 
         if universe in fld.MARKET_MAP_UPPER:
-            is_uni = df["market"] == universe
-        elif universe in fld.INDUSTRY_LIST:
-            is_uni = (df["industry"] == universe) & (df["market"] == fld.MARKET_SET)
-        elif universe in fld.SECTOR_LIST:
-            is_uni = (df["sector"] == universe) & (df["market"] == fld.MARKET_SET)
-        elif universe[:-2] in fld.INDUSTRY_LIST and universe.endswith("-M"):
-            is_uni = (df["industry"] == universe[:-2]) & (
-                df["market"] == fld.MARKET_MAI.upper()
-            )
+            uni_typ = "market"
+        elif universe in fld.INDUSTRY_LIST_UPPER:
+            uni_typ = "industry"
+        elif universe in fld.SECTOR_LIST_UPPER:
+            uni_typ = "sector"
         elif universe in self._get_symbol_in_universe():
-            is_uni = df["symbol"] == universe
+            uni_typ = "symbol"
         else:
             raise InputError(
                 f"{universe} is invalid universe. Please read document to check valid universe."
             )
 
+        is_uni = df[uni_typ].str.upper() == universe
+
         tds = self._get_trading_dates()
         df = pd.DataFrame(is_uni.to_dict(), index=pd.DatetimeIndex(tds))
-        df = df.reindex(columns=sorted(df.columns))
+        df = self._reindex(df)
 
         return df
 
@@ -894,9 +883,9 @@ class SETSignalCreator:
         dr = pd.date_range(start=start, end=end)
         df = df.reindex(dr)
 
-        if method != None:
+        if method is not None:
             df = df.fillna(method=method)
-        if fill_value != None:
+        if fill_value is not None:
             df = df.fillna(fill_value)
 
         return df.reindex(index=index)
