@@ -4,16 +4,6 @@ MARKET_MAI = "mai"
 MARKET_MAP = {MARKET_SET: "A", MARKET_MAI: "S"}
 MARKET_MAP_UPPER = {k.upper(): v for k, v in MARKET_MAP.items()}
 
-# SELECT
-#     DISTINCT("N_INDUSTRY")
-# FROM
-#     "SECTOR"
-# WHERE
-#     "F_DATA" = 'I'
-#     AND "D_CANCEL" is null
-# ORDER BY
-#     "N_INDUSTRY"
-
 INDUSTRY_AGRO = "AGRO"
 INDUSTRY_CONSUMP = "CONSUMP"
 INDUSTRY_FINCIAL = "FINCIAL"
@@ -22,23 +12,20 @@ INDUSTRY_PROPCON = "PROPCON"
 INDUSTRY_RESOURC = "RESOURC"
 INDUSTRY_SERVICE = "SERVICE"
 INDUSTRY_TECH = "TECH"
+INDUSTRY_AGRO_MAI = "AGRO-m"
+INDUSTRY_CONSUMP_MAI = "CONSUMP-m"
+INDUSTRY_FINCIAL_MAI = "FINCIAL-m"
+INDUSTRY_INDUS_MAI = "INDUS-m"
+INDUSTRY_PROPCON_MAI = "PROPCON-m"
+INDUSTRY_RESOURC_MAI = "RESOURC-m"
+INDUSTRY_SERVICE_MAI = "SERVICE-m"
+INDUSTRY_TECH_MAI = "TECH-m"
 
 INDUSTRY_LIST = [
     v for k, v in locals().items() if isinstance(k, str) and k.startswith("INDUSTRY_")
 ]
+INDUSTRY_LIST_UPPER = [k.upper() for k in INDUSTRY_LIST]
 
-# SELECT
-#     DISTINCT("N_SECTOR")
-# FROM
-#     "SECTOR"
-# WHERE
-#     "F_DATA" = 'S'
-#     AND "I_MARKET" in ('A', 'S')
-#     AND "D_CANCEL" is null
-# ORDER BY
-#     "N_SECTOR"
-
-# SET SECTOR
 SECTOR_AGRI = "AGRI"
 SECTOR_AUTO = "AUTO"
 SECTOR_BANK = "BANK"
@@ -67,16 +54,19 @@ SECTOR_PROP = "PROP"
 SECTOR_STEEL = "STEEL"
 SECTOR_TOURISM = "TOURISM"
 SECTOR_TRANS = "TRANS"
+SECTOR_AGRO_MAI = "AGRO-ms"
+SECTOR_CONSUMP_MAI = "CONSUMP-ms"
+SECTOR_FINCIAL_MAI = "FINCIAL-ms"
+SECTOR_INDUS_MAI = "INDUS-ms"
+SECTOR_PROPCON_MAI = "PROPCON-ms"
+SECTOR_RESOURC_MAI = "RESOURC-ms"
+SECTOR_SERVICE_MAI = "SERVICE-ms"
+SECTOR_TECH_MAI = "TECH-ms"
 
 SECTOR_LIST = [
     v for k, v in locals().items() if isinstance(k, str) and k.startswith("SECTOR_")
 ]
-
-# SELECT
-#     DISTINCT("SECTOR"."N_SECTOR")
-# FROM
-#     "SECURITY_INDEX"
-#     JOIN "SECTOR" USING("I_SECTOR")
+SECTOR_LIST_UPPER = [k.upper() for k in SECTOR_LIST]
 
 INDEX_SETWB = "SETWB"
 INDEX_SETTHSI = "SETTHSI"
@@ -252,45 +242,30 @@ Q_TOTAL_REVENUE = Y_TOTAL_REVENUE = "total_revenue"
 Q_EPS = Y_EPS = "eps"
 
 
-D_INDEX_HIGH = "high"
-D_INDEX_LOW = "low"
-D_INDEX_CLOSE = "close"
-D_INDEX_TRI = "tri"
+D_SECTOR_PRIOR = D_INDUSTRY_PRIOR = D_INDEX_PRIOR = "prior"
+D_SECTOR_OPEN = D_INDUSTRY_OPEN = D_INDEX_OPEN = "open"
+D_SECTOR_HIGH = D_INDUSTRY_HIGH = D_INDEX_HIGH = "high"
+D_SECTOR_LOW = D_INDUSTRY_LOW = D_INDEX_LOW = "low"
+D_SECTOR_CLOSE = D_INDUSTRY_CLOSE = D_INDEX_CLOSE = "close"
+D_SECTOR_TRANS = D_INDUSTRY_TRANS = D_INDEX_TRANS = "trans"
+D_SECTOR_VOLUME = D_INDUSTRY_VOLUME = D_INDEX_VOLUME = "volume"
+D_SECTOR_VALUE = D_INDUSTRY_VALUE = D_INDEX_VALUE = "value"
+D_SECTOR_MKT_PE = D_INDUSTRY_MKT_PE = D_INDEX_MKT_PE = "mkt_pe"
+D_SECTOR_MKT_PBV = D_INDUSTRY_MKT_PBV = D_INDEX_MKT_PBV = "mkt_pbv"
+D_SECTOR_MKT_YIELD = D_INDUSTRY_MKT_YIELD = D_INDEX_MKT_YIELD = "mkt_yield"
+D_SECTOR_MKT_CAP = D_INDUSTRY_MKT_CAP = D_INDEX_MKT_CAP = "mkt_cap"
+D_SECTOR_TURNOVER = D_INDUSTRY_TURNOVER = D_INDEX_TURNOVER = "turnover"
+D_SECTOR_SHARE_LISTED_AVG = (
+    D_INDUSTRY_SHARE_LISTED_AVG
+) = D_INDEX_SHARE_LISTED_AVG = "share_listed_avg"
+D_SECTOR_BETA = D_INDUSTRY_BETA = D_INDEX_BETA = "beta"
+D_SECTOR_TURNOVER_VOLUME = (
+    D_INDUSTRY_TURNOVER_VOLUME
+) = D_INDEX_TURNOVER_VOLUME = "turnover_volume"
+D_SECTOR_12M_DVD_YIELD = (
+    D_INDUSTRY_12M_DVD_YIELD
+) = D_INDEX_12M_DVD_YIELD = "12m_dvd_yield"
 
-D_INDEX_TOTAL_TRANS = "total_trans"
-D_INDEX_TOTAL_VOLUME = "total_volume"
-D_INDEX_TOTAL_VALUE = "total_value"
-D_INDEX_MKT_PE = "mkt_pe"
-D_INDEX_MKT_PBV = "mkt_pbv"
-D_INDEX_MKT_YIELD = "mkt_yield"
-D_INDEX_MKT_CAP = "mkt_cap"
-D_INDEX_MKT_PAR_VALUE = "mkt_par_value"
-D_INDEX_TRADING_DAY = "trading_day"
-D_INDEX_NEW_COMPANY = "new_company"
-D_INDEX_DELISTED_COMPANY = "delisted_company"
-D_INDEX_MOVE_IN_COMPANY = "move_in_company"
-D_INDEX_MOVE_OUT_COMPANY = "move_out_company"
-D_INDEX_LISTED_COMPANY = "listed_company"
-D_INDEX_LISTED_STOCK = "listed_stock"
-
-
-D_SECTOR_PRIOR = D_INDUSTRY_PRIOR = "prior"
-D_SECTOR_OPEN = D_INDUSTRY_OPEN = "open"
-D_SECTOR_HIGH = D_INDUSTRY_HIGH = "high"
-D_SECTOR_LOW = D_INDUSTRY_LOW = "low"
-D_SECTOR_CLOSE = D_INDUSTRY_CLOSE = "close"
-D_SECTOR_TRANS = D_INDUSTRY_TRANS = "trans"
-D_SECTOR_VOLUME = D_INDUSTRY_VOLUME = "volume"
-D_SECTOR_VALUE = D_INDUSTRY_VALUE = "value"
-D_SECTOR_MKT_PE = D_INDUSTRY_MKT_PE = "mkt_pe"
-D_SECTOR_MKT_PBV = D_INDUSTRY_MKT_PBV = "mkt_pbv"
-D_SECTOR_MKT_YIELD = D_INDUSTRY_MKT_YIELD = "mkt_yield"
-D_SECTOR_MKT_CAP = D_INDUSTRY_MKT_CAP = "mkt_cap"
-D_SECTOR_TURNOVER = D_INDUSTRY_TURNOVER = "turnover"
-D_SECTOR_SHARE_LISTED_AVG = D_INDUSTRY_SHARE_LISTED_AVG = "share_listed_avg"
-D_SECTOR_BETA = D_INDUSTRY_BETA = "beta"
-D_SECTOR_TURNOVER_VOLUME = D_INDUSTRY_TURNOVER_VOLUME = "turnover_volume"
-D_SECTOR_12M_DVD_YIELD = D_INDUSTRY_12M_DVD_YIELD = "12m_dvd_yield"
 
 DAILY_STOCK_TRADE_MAP = {
     D_PRIOR: "Z_PRIOR",
@@ -477,31 +452,6 @@ FINANCIAL_STAT_STD_MAP_COMPACT = {
     k: v for i in FINANCIAL_STAT_STD_MAP.values() for k, v in i.items()
 }
 
-MKTSTAT_DAILY_INDEX_MAP = {
-    D_INDEX_HIGH: "R_INDEX_HIGH",
-    D_INDEX_LOW: "R_INDEX_LOW",
-    D_INDEX_CLOSE: "R_INDEX_CLOSE",
-    D_INDEX_TRI: "R_TRI",
-}
-
-MKTSTAT_DAILY_MARKET_MAP = {
-    D_INDEX_TOTAL_TRANS: "Q_TOTAL_TRANS",
-    D_INDEX_TOTAL_VOLUME: "Q_TOTAL_VOLUME",
-    D_INDEX_TOTAL_VALUE: "M_TOTAL_VALUE",
-    D_INDEX_MKT_PE: "M_MKT_PE",
-    D_INDEX_MKT_PBV: "M_MKT_PBV",
-    D_INDEX_MKT_YIELD: "M_MKT_YIELD",
-    D_INDEX_MKT_CAP: "M_MKT_CAP",
-    D_INDEX_MKT_PAR_VALUE: "M_MKT_PAR_VALUE",
-    D_INDEX_TRADING_DAY: "Q_TRADING_DAY",
-    D_INDEX_NEW_COMPANY: "Q_NEW_COMPANY",
-    D_INDEX_DELISTED_COMPANY: "Q_DELISTED_COMPANY",
-    D_INDEX_MOVE_IN_COMPANY: "Q_MOVE_IN_COMPANY",
-    D_INDEX_MOVE_OUT_COMPANY: "Q_MOVE_OUT_COMPANY",
-    D_INDEX_LISTED_COMPANY: "Q_LISTED_COMPANY",
-    D_INDEX_LISTED_STOCK: "Q_LISTED_STOCK",
-}
-
 
 DAILY_SECTOR_INFO_MAP = {
     D_SECTOR_PRIOR: "R_INDEX_PRIOR",
